Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/Ultimaker/Cura.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGhostkeeper <rubend@tutanota.com>2019-07-26 14:18:35 +0300
committerGhostkeeper <rubend@tutanota.com>2019-07-26 14:18:47 +0300
commit5a03ace239a31929731550006196c30677802b7e (patch)
tree08849bf2108b07ea7d80d7f3776cddb2ade9e2a1 /scripts
parentd1c4b639717f1efd26209278140264a702308858 (diff)
Also discover Uranium translation directory
Contributes to issue CURA-6663.
Diffstat (limited to 'scripts')
-rw-r--r--scripts/lionbridge_import.py21
1 files changed, 18 insertions, 3 deletions
diff --git a/scripts/lionbridge_import.py b/scripts/lionbridge_import.py
index a876a90cfd..dae1fe416c 100644
--- a/scripts/lionbridge_import.py
+++ b/scripts/lionbridge_import.py
@@ -2,6 +2,7 @@
# Cura is released under the terms of the LGPLv3 or higher.
import argparse #To get the source directory from command line arguments.
+import os #To find files from the source.
import os.path #To find files from the source and the destination path.
## Imports translation files from Lionbridge.
@@ -13,12 +14,26 @@ import os.path #To find files from the source and the destination path.
# preserved.
def lionbridge_import(source: str) -> None:
print("Importing from:", source)
- print("Importing to:", destination())
+ print("Importing to Cura:", destination_cura())
+ print("Importing to Uranium:", destination_uranium())
-## Gets the destination path to copy the translations to.
-def destination() -> str:
+## Gets the destination path to copy the translations for Cura to.
+def destination_cura() -> str:
return os.path.abspath(os.path.join(__file__, "..", "..", "resources", "i18n"))
+## Gets the destination path to copy the translations for Uranium to.
+def destination_uranium() -> str:
+ try:
+ import UM
+ except ImportError:
+ relative_path = os.path.join(__file__, "..", "..", "..", "Uranium", "resources", "i18n", "uranium.pot")
+ print(os.path.abspath(relative_path))
+ if os.path.exists(relative_path):
+ return os.path.abspath(relative_path)
+ else:
+ raise Exception("Can't find Uranium. Please put UM on the PYTHONPATH or put the Uranium folder next to the Cura folder.")
+ return os.path.abspath(os.path.join(UM.__file__, "..", "..", "resources", "i18n"))
+
if __name__ == "__main__":
argparser = argparse.ArgumentParser(description = "Import translation files from Lionbridge.")
argparser.add_argument("source")